class CommitsController < ApplicationController
  before_action :set_commit, only: [:show, :edit, :update, :destroy]

  # GET /commits
  # GET /api/commits
  def index
    @commits = Commit.joins(:developer).select(:commit_hash, :email, :date_created)
    render_json_for_api @commits
  end

  # GET /commits/1
  # GET api/commits/1
  def show
    if @commit == nil
      flash[:error] = "Error: Commit Not Found"
      redirect_to controller: 'commits', :action => 'index'
    else
      render_json_for_api @commit
    end
  end
  # GET api/commits/1/developer
  def developer
    render_json_for_api Commit.find(params[:commit_id]).developer
  end

  private
    # Use callbacks to share common setup or constraints between actions.
    def set_commit
      if params[:id].match(/^(\d)+$/).present?
        @commit = Commit.find_by(id: params[:id])
      else
        @commit = Commit.find_by("commit_hash LIKE ?", "%#{params[:id]}%")
      end

      if @commit == nil
        flash[:error] = "Error: Ambiguous Commit Hash"
        redirect_to controller: 'commits', :action => 'index'
      end
    end

    # Never trust parameters from the scary internet, only allow the white list through.
    def commit_params
      params.fetch(:commit, {})
    end
end
