class StatusController < ApplicationController

  # GET /status
  def index
    # We want to format our numbers nicely, so here's the convention
    #  - Intermediate numbers are NOT attributes, e.g. num_vulns
    #  - Anything formatted for report is an @foo_report
    #  - Be sure to call our "friendly" methods or make your own
    num_vulns = Vulnerability.count
    @num_vulns_report = friendly_int(num_vulns)

    @num_projects_report = friendly_int(Project.count)
    @project_data = Project.select(:fullname, :subdomain)

    num_fixes = Fix.count
    @num_fixes_report = friendly_int(num_fixes)

    @num_vccs = Vcc.count
    @num_vccs_report = friendly_int(@num_vccs)

    num_w_fixes = Fix.select(:vulnerability_id).distinct.count
    @num_w_fix_report = friendly_int(num_w_fixes)
    @perc_w_fixes = num_w_fixes / num_vulns.to_f
    @perc_w_fixes_report = friendly_perc(@perc_w_fixes)

    num_w_vcc = Vcc.select(:vulnerability_id).distinct.count
    @num_w_vcc_report = friendly_int(num_w_vcc)
    @perc_w_vccs = num_w_vcc / num_vulns.to_f
    @perc_w_vccs_report = friendly_perc(@perc_w_vccs)

    @word_count_report = friendly_int(Vulnerability.word_count)

    num_curated = Vulnerability.curated.count
    @num_curated_report = friendly_int(num_curated)
    @perc_curated = num_curated / num_vulns.to_f
    @perc_curated_report = friendly_perc(@perc_curated)

    num_tags = Tag.count
    @num_tags_report = friendly_int(num_tags)

    num_tagged = VulnerabilityTag.count
    @avg_tagged = num_tagged / num_vulns.to_f
    @avg_tagged_report = friendly_dec(@avg_tagged)

    @num_lessons = friendly_int(Tag.lessons.count)

    num_events = Event.count
    @num_events_report = friendly_int(num_events)
    @events_per_vuln_report = friendly_dec(num_events / num_vulns.to_f)

    @num_articles_report = friendly_int(Article.count)
  end

  private

  def friendly_int(i)
    ActiveSupport::NumberHelper.number_to_delimited(i, :delimiter => ',')
  end

  def friendly_dec(f)
    "%.1f" % f
  end

  def friendly_perc(f)
    "%.1f%%" % (100.0 * f)
  end
end
