/*
 Generic table to be used for commits
 Lists the commit no., commit message, and commit date
 Currently being used on filepaths/show, but should be reused as needed
 */

function buildTopNav() {
    $('#datatable_wrapper').prepend('<div id="table-nav-top"></div>');
    const nav = $('#table-nav-top');
    nav.addClass('table-nav grid-x');

    const nav_length = $('#datatable_length');
    nav_length.addClass('table-nav-show-entries cell small-9')
    nav.append(nav_length);

    const nav_search = $('#datatable_filter label');
    nav_search.addClass('table-nav-search cell small-3')
    nav.append(nav_search);
}

function commitsLanguageInfo() {
    return {
        search: "", // nothing in the placeholder;
        searchPlaceholder: 'Search',
        lengthMenu: 'Show _MENU_',
        info: "Showing _START_ to _END_ of _TOTAL_ commits",
        infoEmpty: "Showing 0 to 0 of 0 entries",
        infoFiltered: "(filtered from _MAX_ total commits)",
    };
}

function renderAsDiv(data, row) {
    return `<a class="dt_row" href="/commits/${row.id}">
              <div class="edit-cell-overflow">${data}</div>
            </a>`;
}

function editsTable(jsonData, tableName = '#edit_table') {
    $(tableName).dataTable({
        responsive: true,
        autoWidth: false, // Disable auto-width to prevent table from switching to responsive mode
        destroy: true,
        data: jsonData,
        order: [[2, "desc"]], /* Default sort */
        columnDefs: [],
        columns: [
            {
                title: 'Commit No',
                data: 'commit_hash',
                defaultContent: '',
                className: 'title',
                render: (data, type, row) => renderAsDiv(data, row)
            },
            {
                title: 'Commit Message',
                data: 'message',
                defaultContent: '',
                render: (data, type, row) => renderAsDiv(data, row)
            },
            {
                title: 'Date',
                data: 'date_created',
                defaultContent: '',
                render: (data, type, row) => renderAsDiv(data, row)
            }
            ],
        language: commitsLanguageInfo(),
        preDrawCallback: (settings) => hideSinglePagePagination(settings),
        initComplete: function () {
            $('#loading').remove();
            buildTopNav();
        }
    });

    $(tableName).on('mouseover', 'tbody tr', function () {
        $(this).css({
            'cursor': 'pointer',
            'color': 'blue'
        });
    })

    $(tableName).on('mouseout', 'tbody tr', function () {
        $(this).css({
            'cursor': 'default',
            'color': 'inherit'
        });
    });
};
