import $ from 'jquery'
import 'datatables.net'
import 'datatables.net-responsive-dt'
import 'datatables.net-zf'
import {hideSinglePagePagination} from 'global/datatablesTweaks'

$.urlParam = function(name){
    var results = new RegExp('[\?&]' + name + '=([^&#]*)').exec(window.location.href);
    if (results==null){
       return '';
    }
    else{
       var values = ['Project:', 'CWE', 'Language', 'Lesson', 'Severity:', 'Subsystem'];
       var search = decodeURI(results[1]) || 0;
       if (values.includes(search)){
         return search;
       }
       return '';
    }
}

function buildTopNav() {
    $('#datatable_wrapper').prepend('<div id="table-nav-top"></div>');
    const nav = $('#table-nav-top');
    nav.addClass('table-nav grid-x');

    const nav_length = $('#datatable_length');
    nav_length.addClass('table-nav-show-entries cell small-9')
    nav.append(nav_length);

    const nav_search = $('#datatable_filter label');
    nav_search.addClass('table-nav-search cell small-3')
    nav.append(nav_search);
}

function languageInfo() {
    return {
        search: "", // nothing in the placeholder;
        searchPlaceholder: 'Search',
        lengthMenu: "Show _MENU_",
        info: "Showing _START_ to _END_ of _TOTAL_ tags",
        infoEmpty: "Showing 0 to 0 of 0 entries",
        infoFiltered: "(filtered from _MAX_ total tags)",
    };
}

$( document ).ready( function() {
    $.ajax({
        url: "/api/tags",
        dataType: 'json',
        success: function (jsonData) {
            $('#datatable').dataTable({
                "search": {"search": $.urlParam('search')},
                responsive: true,
                destroy: true,
                data: jsonData,
                pageLength: 50,
                preDrawCallback: (settings) => hideSinglePagePagination(settings),
                columns: [
                    {
                        title: '<i class="vhp-icon-tags"></i> Tag',
                        data: null,
                        defaultContent: '',
                        responsivePriority: 1,
                        render: function(data, type, row) {
                            const icon = '<i class="vhp-icon-' + data.icon + '" style="color: ' + data.color + '"></i> '
                            return renderAsLink(icon + data.name, row)
                        }
                    },
                    {
                        title: 'Description',
                        responsivePriority: 2,
                        data: 'short_desc',
                        defaultContent: '',
                        render: (data, type, row) => renderAsLink(data, row)
                    }
                ],
                language: languageInfo(),
                initComplete: function () {
                    $('#loading').remove();
                    buildTopNav();
                }
            });
        }
    });
        $('#datatable').on('mouseover', 'tbody tr', function() {
            $(this).css({
                'cursor': 'pointer',
                'color': 'blue'
            });
        })

        $('#datatable').on('mouseout', 'tbody tr', function() {
            $(this).css({
                'cursor': 'default',
                'color': 'inherit'
            });
        })
});

function renderAsLink(data, row) {
    return '<a class="dt_row" href="/tags/' + row.id + '">' + data + '</a>';
}
