import $ from 'jquery'
import _ from 'lodash'
import 'datatables.net'
import 'datatables.net-responsive-dt'
import 'datatables.net-zf'
import {vulnLink, vulnProject, vulnName, friendlyCWE} from '../global/dataToPrettyStrings'
import {hideSinglePagePagination} from '../global/datatablesTweaks'
import {shortDate} from 'global/dates'
/*
 Main listing of all vulnerabilities
*/
export function vulnTable(jsonData, tagMap, tableName = '#datatable') {
  return $(tableName).dataTable({
    responsive: true,
    destroy: true,
    data: jsonData,
    order: [ [3, "desc"] ], /* Default sort */
    columns: columnsInfo(tagMap),
    language: languageInfo(),
    preDrawCallback: (settings) => hideSinglePagePagination(settings),
    initComplete: function() {
      buildTopNav(tagMap);
      this.api().columns(4).every(function() {
        var column = this;
        $('#tag_filters').on('change', function() {
            column.search($(this).val()).draw();
            $('.table-nav-more-about-link').hide();
            var tag_id = $(this).find(':selected').data('tag-id');
            $('#table-nav-tag-' + tag_id).show();
        });

      });
    }
  });
  $(tableName).on('mouseover', 'tbody tr', function() {
    $(this).css({
      'cursor': 'pointer',
      'color': 'blue'
    });
  });
  $(tableName).on('mouseout', 'tbody tr', function() {
    $(this).css({
      'cursor': 'default',
      'color': 'inherit'
    });
  })
}

export function updateVulnTable(tbl, jsonData) {
  tbl.api().rows.add(jsonData)
  tbl.api().draw()
}

function columnsInfo(tagMap) {
  return [{
      title: '<i class="vhp-icon-vulnerability"></i> Vulnerability',
      data: null,
      defaultContent: '',
      class: 'text-center',
      responsivePriority: 1,
      width: '12em',
      render: (data) => vulnLink(data, vulnProject(data) + vulnName(data)),
    },
    {
      title: '<i class="vhp-icon-info"></i> Description',
      data: null,
      defaultContent: '',
      class: 'text-left',
      responsivePriority: 3,
      render: (data) => vulnLink(data, data.short_desc)
    },
    {
      title: '<i class="vhp-icon-announce"></i> Date',
      data: null,
      defaultContent: '',
      class: 'text-center',
      responsivePriority: 5,
      width: '10em',
      render: (data) => vulnLink(data, shortDate(data.announced))
    },
    {
      title: '<i class="vhp-icon-upvote"></i>',
      data: 'upvotes',
      defaultContent: '0',
      class: 'text-center',
      responsivePriority: 2,
    },
    {
      title: '<i class="vhp-icon-tags"></i> Tags',
      data: null,
      defaultContent: '',
      width: '40%',
      class: 'text-left',
      responsivePriority: 4,
      render: (data) => renderTags(data, tagMap)
    }
  ]
}

function languageInfo() {
  return {
    search: "", // nothing in the placeholder;
    searchPlaceholder: 'Search',
    lengthMenu: "Show _MENU_",
    info: "Showing _START_ to _END_ of _TOTAL_ vulnerabilities",
    infoEmpty: "Showing 0 to 0 of 0 entries",
    infoFiltered: "(filtered from _MAX_ total vulnerabilities)",
  };
}

function buildTopNav(tagMap) {
  $('#datatable_wrapper').prepend('<div id="table-nav-top"></div>');
  var nav = $('#table-nav-top');

  nav.addClass('table-nav grid-x');

  var nav_length = $('#datatable_length');
  nav_length.addClass('table-nav-show-entries cell small-2')
  nav.append(nav_length);

  nav.append(`
    <div class="table-nav-filter cell small-3">
      <select id="tag_filters" name="tag_filters" class="tag-filter">
        <option selected value> --- Filter by Tags --- </option>
      </select>
    </div>`
  );

  _.each(tagMap, function(tag, _id) {
    $('#tag_filters').append(
      `<option value="${tag.name}" data-tag-id="${tag.shortname}">
      ${tag.name}
      </option>`
    )
    $('.table-nav-more-about').append(
      `<a href="/tags/${tag.shortname}" class="table-nav-more-about-link"
          id="table-nav-tag-${tag.shortname}">
          <i class="vhp-icon-${tag.icon}" style="color: ${tag.color}"/></i>
          Learn about ${tag.name}
      </a>`
    )
  })
  $('.table-nav-more-about-link').hide();

  nav.append(`
    <div class="table-nav-more-about text-center cell small-4">
    <!-- ajax call to /api/tags will populate here -->
    </div>
  `);

  var nav_search = $('#datatable_filter label');
  nav_search.addClass('table-nav-search cell small-3')
  nav.append(nav_search);
}

function renderTags(vuln, tagMap) {
  let str = "<span class='tag-list'>";
  for (let t of vuln.tag_json) {
    const tag = tagMap[t.id]
    str += `
      <a href="/tags/${tag.shortname}" class='tag-list-item'>
        <i class='vhp-icon-${tag.icon}' style="color: ${tag.color}" ></i>
        <span>${friendlyCWE(tag.name)}</span>
      </a>
    `;
  }
  str += "</span>";
  return str;
}
