class Commit < ApplicationRecord
  has_many :commit_filepaths, foreign_key: 'commit_id'
  belongs_to :developer, foreign_key: 'author_id'
  has_many :filepaths, through: :commit_filepaths
  has_many :vccs, foreign_key: 'commit_id'
  has_many :fixes, foreign_key: 'commit_id'
  has_many :events, as: :detail

  # Required by Event model association
  def title
    message.to_s.each_line.to_a[0].to_s.strip
  end

  def message_without_title
    message.to_s.each_line.to_a[1..-1].join.strip
  end

  # TODO This is not ideal. See issue #806
  def project
    filepaths[0].project
  end

  # Required by Event model association
  def description
    remove_hardwrapping(message)
  end

  # Required by Event model association
  def type
    "commit"
  end

  # Required by Event model association
  def date
    date_created
  end

  def remove_hardwrapping(str)
    str.gsub /(?<!\n)\n(?!\n)/, ' '
  end

  def github_url
    "#{filepaths[0].project.git_commit_url_prefix}+#{commit_hash}"
  end

end
