require_relative '../../app/helpers/application_helper'

class BountyEvents
  include ApplicationHelper

  def initialize(project)
    @project = project
    @desc = Writing.event_article('bounty')
  end

  def generate
    Vulnerability.where(project: @project).each do |vuln|
      if has_bounty? vuln
        if valid_date? vuln, vuln.notes['bounty']['date']
          Event.create!(
            title: "Bounty awarded for #{vuln.cve}",
            event_type: 'bounty',
            date: vuln.notes['bounty']['date'],
            description: Writing.embed_details(@desc, vuln),
            icon: 'monetization_on',
            color: '#25C322',
            notes: {},
            vulnerability: vuln,
            start_hidden: false
          )
        end
      end
    end
  end

  private

  # Returns true if the vulnerability has a bounty
  def has_bounty?(v)
    !v.notes['bounty']['amount'].nil?
  end

  def valid_date?(vuln, str)
    begin
      Date.parse(str.to_s)
    rescue ArgumentError
      puts "ERROR on #{vuln.cve}: Bounty Date incorrect"
      return false
    end
    return true
  end

end
