require_relative '../../app/helpers/application_helper'

class FixEvents
  include ApplicationHelper

  def initialize(project, log = TimingLogger.new(STDOUT, 'data:events:fixes'))
    @project = project
    @logger = log
    @desc = Writing.event_article('fix')
  end

  def fixes
    Fix.joins(:vulnerability).where('vulnerabilities.project_id' => @project.id)
  end

  def generate
    events = []
    @logger.info "Building model objects"
    fixes.each do |fix|
      e = Event.new(
        title: "Fix for #{fix.vulnerability.cve}: #{fix.commit.title}",
        date: fix.commit.date,
        event_type: 'fix',
        description: Writing.embed_details(@desc, fix),
        icon: 'lock',
        color: '#9FE69F',
        notes: {},
        vulnerability_id: fix.vulnerability_id,
        start_hidden: false
      )
      events << e
    end
    @logger.info "Importing events"
    Event.import events
  end

end
