require_relative '../../app/helpers/application_helper'

class VccEvents
  include ApplicationHelper

  def initialize(project, log = TimingLogger.new(STDOUT, 'data:events:vccs'))
    @project = project
    @logger = log
    @desc = Writing.event_article('vcc')
  end

  def vccs
    Vcc.joins(:vulnerability).where('vulnerabilities.project_id' => @project.id)
  end

  def generate
    events = []
    @logger.info "Building model objects"
    vccs.each do |vcc|
      e = Event.new(
        title: "Vulnerability-contributing commit for #{vcc.vulnerability.cve}: #{vcc.commit.title}",
        date: vcc.commit.date,
        event_type: 'vcc',
        description: Writing.embed_details(@desc, vcc),
        icon: 'report_problem',
        color: '#ED6049',
        notes: {},
        start_hidden: false,
        vulnerability_id: vcc.vulnerability_id
      )
      events << e
    end
    @logger.info "Importing events"
    Event.import events
  end
end
