require_relative '../writing'

class CVSSTagger

  def initialize(project)
    @project = project

    @codes_to_names = {
      'AV:N' => 'Attack Vector - Network',
      'AV:A' => 'Attack Vector - Adjacent Network',
      'AV:L' => 'Attack Vector - Local',
      'AV:P' => 'Attack Vector - Physical',
      'AC:L' => 'Attack Complexity - Low',
      'AC:M' => 'Attack Complexity - Medium',
      'AC:H' => 'Attack Complexity - High',
      'Au:M' => 'Privileges Required - High',
      'PR:H' => 'Privileges Required - High',
      'Au:S' => 'Privileges Required - Low',
      'PR:L' => 'Privileges Required - Low',
      'Au:N' => 'Privileges Required - None',
      'PR:N' => 'Privileges Required - None',
      'UI:R' => 'User Interaction - Required',
      'UI:N' => 'User Interaction - None',
      'S:C' => 'Scope - Changed',
      'S:U' => 'Scope - Unchanged',
      'C:C' => 'Confidentiality Impact - Complete',
      'C:H' => 'Confidentiality Impact - High',
      'C:P' => 'Confidentiality Impact - Partial',
      'C:L' => 'Confidentiality Impact - Low',
      'I:C' => 'Integrity Impact - Complete',
      'I:H' => 'Integrity Impact - High',
      'I:P' => 'Integrity Impact - Partial',
      'I:L' => 'Integrity Impact - Low',
      'A:C' => 'Availability Impact - Complete',
      'A:H' => 'Availability Impact - High',
      'A:P' => 'Availability Impact - Partial',
      'A:L' => 'Availability Impact - Low',
    }

    @all_tags = Hash.new
    @codes_to_names.each do |code, fullname|
      fields = fullname.split(' - ')
      @all_tags[code] = {
        name: "Severity: #{fullname}",
        shortname: shortname(code),
        color: '#99ccff',
        description: Writing.tag_article(shortname(code))
      }
    end
  end

  def shortname(code)
    "cvss-#{code.parameterize}"
  end

  def create_tags
    @cvss_tags = Hash.new
    Vulnerability.where(project: @project).each do |v|
      if v.notes.dig("CVSS") != nil
        cvss = v.notes.dig('CVSS')
        fields = cvss.split('/')
        for field in fields
          if @all_tags.has_key?(field)
            t = Tag.find_or_create_by!(@all_tags[field])
            @cvss_tags[field] = t
          end
        end
      end
    end
  end

  def apply_tags
    vuln_tags = []
    Vulnerability.where(project: @project).each do |v|
      if v.notes.dig("CVSS") != nil
        fields = v.notes.dig("CVSS").split('/')
        for field in fields
          t = @cvss_tags[field]
          vuln_tags << VulnerabilityTag.new(
            vulnerability: v,
            tag: t,
            importance: importance(field),
            note: ''
          )
        end
      end
    end
    VulnerabilityTag.import vuln_tags
  end

  # These are based on my totally unscientific understanding of severity
  # comparisons.
  # I'd LOVE to see some rigorous science on these importance measures.
  # But even FIRST can't be bothered to be transparent about they came up with
  # their (frankly weird) weights. There's no science on this yet.
  # So I'm gonna pull this out of my ass because apparently that's allowed.
  def importance(field)
    case field
    when 'AV:N' then 0.5
    when 'AV:A' then 0.2
    when 'AV:L' then 0.1
    when 'AV:P' then 0.1
    when 'AC:L' then 0.5
    when 'AC:M' then 0.2
    when 'AC:H' then 0.1
    when 'Au:M' then 0.2
    when 'PR:H' then 0.2
    when 'Au:S' then 0.2
    when 'PR:L' then 0.2
    when 'Au:N' then 0.6
    when 'PR:N' then 0.6
    when 'UI:R' then 0.1
    when 'UI:N' then 0.8
    when 'S:C' then 0.5
    when 'S:U' then 0.3
    when 'C:C' then 0.7
    when 'C:H' then 0.7
    when 'C:P' then 0.3
    when 'C:L' then 0.1
    when 'I:C' then 0.7
    when 'I:H' then 0.7
    when 'I:P' then 0.5
    when 'I:L' then 0.1
    when 'A:C' then 0.7
    when 'A:H' then 0.7
    when 'A:P' then 0.5
    when 'A:L' then 0.1
    else 0.0
    end
  end

end
