require_relative '../writing'

class BountyTagger

  def initialize(project)
    @project = project
  end

  def create_tags
    @bounty_tag = Tag.find_or_create_by!(
      name: 'Bounty Awarded',
      shortname: 'bounty',
      color: '#25C322',
      icon: 'money',
      description: Writing.tag_article('bounty')
    )
  end

  def apply_tags
    Vulnerability.where(project: @project).each do |v|
      begin
      if has_bounty?(v)
        VulnerabilityTag.create!(
          vulnerability: v,
          tag: @bounty_tag,
          note: "$#{v.notes.dig('bounty', 'amount').to_s} awarded.",
          importance: importance(v.notes.dig('bounty', 'amount').to_s.to_f)
        )
      end
      rescue
        require 'byebug'; byebug
      end
    end
  end

  # We're going to mark the importance of a bounty tag according to our
  # unscientific method roughly based on logarithm
  def importance(bounty)
    case bounty
    when 0.0              then 0.0
    when 0.01..1000.0     then 0.25
    when 1000.01..10000   then 0.75
    when 10000.01..100000 then 0.95
    else 0.99 # over $100k?!?! wow.
    end
  end

  def has_bounty?(v)
    v.notes.dig('bounty', 'amount').to_i > 0
  end
end
