require 'csv'

class CWETagger

  def initialize(project)
    @logger = TimingLogger.new(STDOUT, 'data:tag:cwe')
    @project = project
    @tagged_cwes = {}
    CSV.foreach(Rails.root + "lib/taggers/resources/cwes.csv") do |fields|
      @tagged_cwes[fields[0].to_i] = {
        name: "CWE-#{fields[0]}: #{fields[1]}",
        shortname: "cwe-#{fields[0]}",
        color: '#99ccff',
        description: <<~EOS
          "#{fields[4]}" - For more infomration visit https://cwe.mitre.org/data/definitions/#{fields[0]}.html
          EOS
      }
    end
    CSV.foreach(Rails.root + "lib/taggers/resources/broad_cwes.csv") do |fields|
      @tagged_cwes[fields[0].to_i] = {
        name: "CWE-#{fields[0]}: #{fields[1]}",
        shortname: "cwe-#{fields[0]}",
        color: '#99ccff',
        description: <<~EOS
          "#{fields[2]}" - For more infomration visit https://cwe.mitre.org/data/definitions/#{fields[0]}.html
          EOS
      }
    end
  end

  def create_tags
    Vulnerability.where(project: @project).each do |v|
      cwe = normalized_cwe_string(v.notes['CWE'])
      if @tagged_cwes.key?(cwe)
        Tag.find_or_create_by!(@tagged_cwes[cwe])
      end
    end
  end

  def apply_tags
    vuln_tags = []
    untagged = []
    Vulnerability.where(project: @project).each do |v|
      if @tagged_cwes.key? normalized_cwe_string(v.notes['CWE'])
        vuln_tags << VulnerabilityTag.new(
          vulnerability: v,
          tag: find_tag(v.notes['CWE']),
          importance: importance,
          note: ''
        )
      else
        @logger.warn "WARNING: Un-tagged CWE: #{v.notes['CWE']} in #{v.cve}" unless v.notes['CWE'].to_s.blank?
        untagged << normalized_cwe_string(v.notes['CWE'])
      end
    end
    VulnerabilityTag.import vuln_tags
  end

  # If people entered in text here, just take the number
  # e.g. CWE-122 ==> 122
  def normalized_cwe_string(cwe)
    cwe.to_s.gsub(/[^0-9]/,'').to_i
  end

  def find_tag(cwe_str)
    shortname = @tagged_cwes[normalized_cwe_string(cwe_str)][:shortname]
    Tag.find_by(shortname: shortname)
  end

  def importance
    1.0 # CWE should always come first in the tag sort order if we have it
  end

end
