require 'test_helper'

class CvesControllerTest < ActionDispatch::IntegrationTest  
  test 'Checks basic route functionality' do
    assert_generates '/cves', controller: 'cves', action: 'index'
    assert_routing '/cves', controller: 'cves', action: 'index'
    assert_recognizes({controller: 'cves', action: 'index'}, 'cves')
  end

  test 'check that a cve route works' do
    assert_generates "/cves/CVE-2011-3092", { controller: "cves", action: "show", name: "CVE-2011-3092" }
    assert_routing "/cves/CVE-2011-3092", { controller: "cves", action: "show", name: "CVE-2011-3092" }
    assert_recognizes({ controller: "cves", action: "show", name: "CVE-2011-3092" }, 'cves/CVE-2011-3092')
   end

  test 'test CAN route works' do
    assert_generates "/cves/CAN-2011-3092", { controller: "cves", action: "show", name: "CAN-2011-3092" }
    assert_routing "/cves/CAN-2011-3092", { controller: "cves", action: "show", name: "CAN-2011-3092" }
    assert_recognizes({ controller: "cves", action: "show", name: "CAN-2011-3092" }, 'cves/CAN-2011-3092')
  end

  test "check CVE redirects to the right place" do
    v = vulnerabilities(:cve_2011_3092).id.to_s
    get "/cves/CVE-2011-3092"
    assert_redirected_to "/vulnerabilities/" + v
  end

  test "check mismatched CVE redirects to the right place" do
    v = vulnerabilities(:cve_2011_3092).id.to_s
    get "/cves/cve-2011-3092"
    assert_redirected_to "/vulnerabilities/" + v
  end

  test "check CAN redirects to the right place" do
    v = vulnerabilities(:cve_2011_3092).id.to_s
    get "/cves/CAN-2011-3092"
    assert_redirected_to "/vulnerabilities/" + v
  end

  test "check mismatched CAN redirects to the right place" do
    v = vulnerabilities(:cve_2011_3092).id.to_s
    get "/cves/cAn-2011-3092"
    assert_redirected_to "/vulnerabilities/" + v
  end

  test "check wrong CVE redirects to the right place" do
    get "/cves/CVE-2011-3096"
    assert_redirected_to "/vulnerabilities"
  end

  test "check wrong input redirects to the right place" do
    get "/cves/testing"
    assert_redirected_to "/vulnerabilities"
  end

  test "check wrong CAN redirects to the right place" do
    get "/cves/CAN-2011-3096"
    assert_redirected_to "/vulnerabilities"
  end

  test "check clean_cve work with normal CVE" do
    @controller = CvesController.new
    assert_equal  @controller.clean_cve('CAN-2011-3092'), 'CVE-2011-3092'
  end

  test "check clean_cve work with CAN" do
    @controller = CvesController.new
    assert_equal  @controller.clean_cve('CAN-2011-3092'), 'CVE-2011-3092'
  end

  test "check clean_cve work with mismatched CAN" do
    @controller = CvesController.new
    assert_equal  @controller.clean_cve('cAn-2011-3092'), 'CVE-2011-3092'
  end

  test "check clean_cve work with mismatched cVe" do
    @controller = CvesController.new
    assert_equal  @controller.clean_cve('cVe-2011-3092'), 'CVE-2011-3092'
  end

  test "check clean_cve work with wrong CVE" do
    @controller = CvesController.new
    assert_nil  @controller.clean_cve('CVE-2011-30966')
  end

  test "check clean_cve work with wrong, mismatched CVE" do
    @controller = CvesController.new
    assert_nil  @controller.clean_cve('cVe-2011-30966')
  end

  test "check clean_cve work with wrong CAN" do
    @controller = CvesController.new
    assert_nil  @controller.clean_cve('CAN-2011-30966')
  end

end
