require 'test_helper'

class FilepathsControllerTest < ActionDispatch::IntegrationTest
  test 'routes to /filepaths' do
    assert_generates '/filepaths', controller: 'filepaths', action: 'index'
    assert_routing '/filepaths', controller: 'filepaths', action: 'index'
    assert_recognizes({controller: 'filepaths', action: 'index'}, 'filepaths')
  end

  test 'routes goes to show from slug' do
    makefile = filepaths(:makefile)
    path = "/filepaths/#{makefile.slug}"
    assert_generates path, { controller: 'filepaths',
                             action: 'show',
                             filepath_id: makefile.slug }
  end

  test 'routes goes to show from slug, part 2' do
    path = "/filepaths/chromium-deps"
    assert_generates path, { controller: 'filepaths',
                             action: 'show',
                             filepath_id: 'chromium-deps' }
  end

  test 'api routes go to dev' do
    path = "/api/filepaths/chromium-deps/developers"
    assert_generates path, { controller: 'filepaths',
                             action: 'developers',
                             filepath_id: 'chromium-deps' }
  end

  test 'api routes go to contributors' do
    path = "/api/filepaths/chromium-deps/contributors"
    assert_generates path, { controller: 'filepaths',
                             action: 'contributors',
                             filepath_id: 'chromium-deps' }
  end

  test 'api routes go to commits' do
    path = "/api/filepaths/chromium-deps/commits"
    assert_generates path, { controller: 'filepaths',
                             action: 'commits',
                             filepath_id: 'chromium-deps' }
  end

  test 'api routes go to vulnerabilities' do
    path = "/api/filepaths/chromium-deps/vulnerabilities"
    assert_generates path, { controller: 'filepaths',
                             action: 'vulnerabilities',
                             filepath_id: 'chromium-deps' }
  end

end
