require 'test_helper'
require 'taggers/lifetime_tagger'

class LifetimeTagTest < ActiveSupport::TestCase

  test 'lifetime tag properly applied' do
    t = LifetimeTagger.new(projects(:one))
    t.create_tags
    t.apply_tags(Logger.new(StringIO.new))
    tag = Tag.find_by(shortname: 'lifetime-3mo')
    assert_includes tag.vulnerabilities.pluck(:cve), 'CVE-2011-3092'
  end

  test 'lifetime tag not applied to negative time periods' do
    strio = StringIO.new
    logger = Logger.new(strio)

    t = LifetimeTagger.new(projects(:one))
    t.create_tags
    t.apply_tags(logger)

    tag = Tag.find_by(shortname: 'lifetime-3mo')
    assert_not_includes tag.vulnerabilities.pluck(:cve), 'CVE-2011-3093'
    assert_match /Lifetime of VCC to fix for CVE-2011-3093 is negative/,
                 strio.string
  end

end
