require 'test_helper'

class CommitTest < ActiveSupport::TestCase
  test 'fixtures are loaded' do
    assert Commit.any?
  end

  test 'commit fixture data are loaded' do
    assert_equal 'f3e8965444b0b615ed8aabfcacc5840f6684c0c5',
                 commits(:fix1).commit_hash
  end

  test 'checks if there is a developer' do
    assert_equal 'dglazkov@google.com', commits(:fix1).developer.email
  end

  test 'commit has a fix commit' do
    fix_hash = 'f3e8965444b0b615ed8aabfcacc5840f6684c0c5'
    c = commits(:fix1)
    assert_equal fix_hash, c.fixes.first.commit.commit_hash
  end

  test 'commits have commit_filepaths' do
    c = commits(:fix1)
    expected = [
      'DEPS',
      'webkit/port/DerivedSources.make',
      "this/is/a/test/1.c"
    ]
    actual = c.commit_filepaths.map { |cf| cf.filepath.filepath }
    assert_equal expected, actual
  end

  test 'commits have filepaths' do
    c = commits(:fix1)
    expected = [
      'DEPS',
      'webkit/port/DerivedSources.make',
      "this/is/a/test/1.c"
    ]
    actual = c.filepaths.map { |f| f.filepath }
    assert_equal expected, actual
  end

  test 'vcc commits have filepaths' do
    c = commits(:vcc1)
    expected = [
      'webkit/port/bindings/v8/v8_custom.cpp',
      'webkit/port/bindings/v8/v8_custom.h',
    ]
    actual = c.filepaths.map { |f| f.filepath }
    assert_equal expected, actual
  end

end
