require 'test_helper'
require 'timing_logger'

class TimingLoggerTest < ActiveSupport::TestCase

  test 'log once' do
    out = StringIO.new
    travel_to Time.zone.parse('1984-05-19 07:35:03')
    log = TimingLogger.new(out, 'prog')
    travel_to Time.zone.parse('1984-05-19 07:35:13') # 10s later
    log.info "log once"

    expected = <<~EOS
[INFO 1984-05-19 07:35:13 prog]                     10s | log once
    EOS

    assert_equal expected, out.string
  end

  test 'log with warnings in between' do
    out = StringIO.new

    travel_to Time.zone.parse('1984-05-19 07:35:03')
    log = TimingLogger.new(out, 'prog')

    travel_to Time.zone.parse('1984-05-19 07:35:13') # 10s later
    log.info "info first"

    travel_to Time.zone.parse('1984-05-19 07:35:15') # 10s later
    log.warn "WARNING"

    travel_to Time.zone.parse('1984-05-19 07:37:13') # 120s since last info
    log.info "info second blah blah"

    expected = <<~EOS
[INFO 1984-05-19 07:35:13 prog]                     10s | info first
[\e[31mWARN\e[0m 1984-05-19 07:35:15 prog]           WARNING
[INFO 1984-05-19 07:37:13 prog]                     120s | info second blah blah
EOS


    assert_equal expected, out.string
  end

end
